@@ -11,9 +11,8 @@ class LogicalVolumeFilter(NetBoxModelFilterSet):
     class Meta:
         model = LogicalVolume
         fields = [
-            "vg",
             "lv_name",
-            "fs",
+            "size",
             "path",
             "description"
         ]
@@ -23,9 +22,8 @@ class LogicalVolumeFilter(NetBoxModelFilterSet):
         if not value.strip():
             return queryset
         qs_filter = (
-            Q(vg__icontains=value)
-            | Q(lv_name__icontains=value)
-            | Q(fs__icontains=value)
+            Q(lv_name__icontains=value)
+            | Q(size__icontains=value)
             | Q(path__icontains=value)
         )
         return queryset.filter(qs_filter)
