@@ -138,6 +138,14 @@ class LVSimpleForm(NetBoxModelForm):
         help_text="The size of the logical volume e.g. 25",
         validators=[MinValueValidator(0.1)],
     )
+    lv_name = CharField(
+        label="LV Name",
+        help_text="The logical volume name e.g. lv_data",
+    )
+    vg_name = CharField(
+        label="VG Name",
+        help_text="The volume group name e.g. vg_data",
+    )
     path = CharField(
         label="Path",
         help_text="The mounted path of the volume e.g. /var/lib/docker",
