@@ -103,7 +103,7 @@ class Partition(NetBoxModel):
         ordering = ["size"]
 
     def __str__(self):
-        return self.device
+        return f'{self.device}'
 
     def get_absolute_url(self):
         return reverse("plugins:netbox_storage:partition", kwargs={"pk": self.pk})
